<div align="center">
  <img src="https://dioptra-resources.s3.us-east-2.amazonaws.com/public_assets/dioptra/images/dioptra_logo_with_text.png" width="400" /><br><br>
</div>

---

## About

Dioptra is a ML intelligence platform. It provides real time observability of models in production as well as error analysis frameworks to understand model performance and inform retraining strategies.

## Quickstart


### 1. Create your account
Sign up for a free account by reaching out to <info@dioptra.ai>.


### 2. Get your service API key
When you create an account, we generate a service API key.


### 3. Instrument your code


### Install Library

Install the Dioptra library in an environment using Python > 3.5.3.
```sh
$ pip3 install dioptra
```

Or clone the repo:
```sh
$ git clone https://github.com/dioptra-ai/collector-py.git
$ python3 setup.py install
```

### Runnin the example

You can run the provided example to get a sense of how Dioptra works

```sh
$ export DIOPTRA_API_KEY=<your_api_key>
$ python3 examples/image_classification.py
```

And log in to the dioptra app to see what happens :)

